#ifndef BINVAL_H
#define BINVAL_H
/*****************************************************************************
Spartan-3 Starter Board to Parallel Port Interface
  ADT representing a string of binary digits.

  Written by Eirik Bakke, January 14, 2006
  See http://www.mit.edu/~ebakke/parint for documentation
  
******************************************************************************/


typedef struct Binval *Binval_T;

/* Create a new binary string of the given width. */
Binval_T Binval_new(int width);

/* Create a new binary string of the given widht and value. */
Binval_T Binval_newval(int width, int val);

/* Create a new binary string based on a substring of another binary string. If
the substring is changed, the original string will be changed and vice versa. */
Binval_T Binval_newsubstring(Binval_T b, int pos, int width);

void     Binval_free();

/* Set the value of this binary string from an integer. */
void Binval_set(Binval_T b, int val);

/* Get the integer value of this binary string. */
int  Binval_get(Binval_T b);

/* Compare the values of two binary strings. Values may be equal even if the
strings are of different lengths. */
int Binval_equal(Binval_T a, Binval_T b);

/* Return a simple character string representation of the binary string. */
char *Binval_tostring(Binval_T b);

/* Return a pointer to an array of booleans (non-zero means 1) representing this
binary string. Changing this array will have the corresponding effect on the
value of the original binary string object. */
int *Binval_toarray(Binval_T b);

/* Return a pointer to a particular binary digit in the binary string. Changing
this value will have the appropriate effect on the value of the original binary
string object. */
int *Binval_digit(Binval_T, int i);

#endif
