#ifndef PARINT_H
#define PARINT_H
/*****************************************************************************
Spartan-3 Starter Board to Parallel Port Interface
  Software interface for getting and setting signals on the parallel port
  interface.
  
  Written by Eirik Bakke, January 14, 2006
  See http://www.mit.edu/~ebakke/parint for documentation
  
******************************************************************************/

#include "binval.h"

/* Initialize for communicating with an interface with the given number of
inputs and outputs (from the FPGA's point of view). The underlying PortTalk
driver will be installed if necessary. */
int  Parint_init(int w_in, int w_out);

/* Free any resources held. */
void Parint_shutdown(void);

/* Return the Binval objects representing the input and output busses to and
from the FPGA, respectively. */
Binval_T Parint_inputs(void);
Binval_T Parint_outputs(void);

/* Exchange data with the FPGA by sending the data on the input object and
receiving data to the output object ("input" and "output" refers to the FPGA's
point of view). The objects stay the same after an update; there is no need to
call Parint_inputs/outputs again. */
void Parint_update(void);

/* Sleep for the specified amount of milliseconds. A value of zero indicates
the shortest permissible time that the parallel port interface circuitry will
react to. This happens to be no explicit delay at all; the system call overhead
is probably the limiting factor in how fast the interface can be driven. */
void Parint_sleep(int millisecs);

/* Uninstall the underlying PortTalk driver. */
void Parint_uninstall(void);

#endif
